# Glitch Face 📺

Anonymize face with pixilation and glitching.

## Features 

1. Works with default webcame
2. Command line utility

## Usage

```
# pip3 install glitch_face

> glitch_face
```

```
glitch_face --help
Usage: glitch_face [OPTIONS]

Options:
  -b INTEGER  blocks: number of NxN blocks to break up the image [0-50]
  -o INTEGER  offset: offset glitch
  -s INTEGER  value to scale width and height of area anonymized
  --help      Show this message and exit.
```

